@@ -113,7 +113,7 @@ $SFLAP_TLV_TAG = 1;
 $SFLAP_HEADER_LEN = 6;
 
 # Net::AOLIM version
-$VERSION = "1.2";
+$VERSION = "1.3";
 
 # number of arguments that server messages have:
 %SERVER_MSG_ARGS = ( 'SIGN_ON' => 1,
@@ -214,7 +214,7 @@ values are optional):
     'login_timeout' => timeout in seconds to wait for a response to the
                        toc_signon packet.  Default is 0 (infinite)
     'aim_agent' => agentname (max 200 char) 
-                Default is AOLIM:$Version 1.2$
+                Default is AOLIM:$Version 1.3$
                 There have been some reports that changing this 
                 may cause TOC servers to stop responding to signon 
                 requests
@@ -1031,9 +1031,9 @@ sub set_srv_buddies
 
     $srv_buddy_list =~ s/^CONFIG://;
 
-    @srv_buddies = split "\n", $srv_buddy_list;
+    return unless (@srv_buddies = split "\n", $srv_buddy_list);
 
-    for ($i=0; $i <= scalar (@srv_buddies); $i++)
+    for ($i=0; $i < scalar (@srv_buddies); $i++)
     {
 	if ($srv_buddies[$i] =~ /^g\s*(.*)/)
 	{
@@ -1750,7 +1750,7 @@ sub toc_chat_invite
     my $tci_msgtext = shift @_;
     my @tci_buddies = @_;
 
-    unless ((defined $tci_roomid) && (defined $tci_msgtext) && (defined @tci_buddies))
+    unless ((defined $tci_roomid) && (defined $tci_msgtext) && (@tci_buddies))
     {
 	$main::IM_ERR = $SFLAP_ERR_ARGS;
 	return undef;
